@@ -46,52 +46,52 @@ fn to_xlsx_roundtrip() {
     wrk.assert_success(&mut cmd2);
 }
 
-#[test]
-fn to_xlsx_dir() {
-    let wrk = Workdir::new("to_xlsx_dir");
+// #[test]
+// fn to_xlsx_dir() {
+//     let wrk = Workdir::new("to_xlsx_dir");
 
-    let cities = vec![
-        svec!["city", "state"],
-        svec!["Boston", "MA"],
-        svec!["New York", "NY"],
-        svec!["San Francisco", "CA"],
-        svec!["Buffalo", "NY"],
-    ];
-    let places = vec![
-        svec!["city", "place"],
-        svec!["Boston", "Logan Airport"],
-        svec!["Boston", "Boston Garden"],
-        svec!["Buffalo", "Ralph Wilson Stadium"],
-        svec!["Orlando", "Disney World"],
-    ];
+//     let cities = vec![
+//         svec!["city", "state"],
+//         svec!["Boston", "MA"],
+//         svec!["New York", "NY"],
+//         svec!["San Francisco", "CA"],
+//         svec!["Buffalo", "NY"],
+//     ];
+//     let places = vec![
+//         svec!["city", "place"],
+//         svec!["Boston", "Logan Airport"],
+//         svec!["Boston", "Boston Garden"],
+//         svec!["Buffalo", "Ralph Wilson Stadium"],
+//         svec!["Orlando", "Disney World"],
+//     ];
 
-    wrk.create("cities.csv", cities.clone());
-    wrk.create("places.csv", places.clone());
+//     wrk.create("cities.csv", cities.clone());
+//     wrk.create("places.csv", places.clone());
 
-    let xlsx_file = wrk.path("testxlsx.xlsx").to_string_lossy().to_string();
-    log::info!("xlsx_file: {}", xlsx_file);
+//     let xlsx_file = wrk.path("testxlsx.xlsx").to_string_lossy().to_string();
+//     log::info!("xlsx_file: {}", xlsx_file);
 
-    let mut cmd = wrk.command("to");
-    cmd.arg("xlsx").arg(xlsx_file.clone()).arg(wrk.path(""));
+//     let mut cmd = wrk.command("to");
+//     cmd.arg("xlsx").arg(xlsx_file.clone()).arg(wrk.path(""));
 
-    wrk.assert_success(&mut cmd);
+//     wrk.assert_success(&mut cmd);
 
-    let mut cmd2 = wrk.command("excel");
-    cmd2.arg(xlsx_file.clone()).args(&["--sheet", "cities"]);
+//     let mut cmd2 = wrk.command("excel");
+//     cmd2.arg(xlsx_file.clone()).args(&["--sheet", "cities"]);
 
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd2);
-    assert_eq!(got, cities);
+//     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd2);
+//     assert_eq!(got, cities);
 
-    wrk.assert_success(&mut cmd2);
+//     wrk.assert_success(&mut cmd2);
 
-    let mut cmd2 = wrk.command("excel");
-    cmd2.arg(xlsx_file).args(&["--sheet", "places"]);
+//     let mut cmd2 = wrk.command("excel");
+//     cmd2.arg(xlsx_file).args(&["--sheet", "places"]);
 
-    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd2);
-    assert_eq!(got, places);
+//     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd2);
+//     assert_eq!(got, places);
 
-    wrk.assert_success(&mut cmd2);
-}
+//     wrk.assert_success(&mut cmd2);
+// }
 
 #[test]
 fn to_datapackage() {
@@ -144,166 +144,166 @@ Description  string      string"#
     assert_json_eq!(expecteddp_json, generated_json);
 }
 
-#[test]
-fn to_datapackage_dir() {
-    let wrk = Workdir::new("to_datapackage_dir");
+// #[test]
+// fn to_datapackage_dir() {
+//     let wrk = Workdir::new("to_datapackage_dir");
 
-    let cities = vec![
-        svec!["city", "state"],
-        svec!["Boston", "MA"],
-        svec!["New York", "NY"],
-        svec!["San Francisco", "CA"],
-        svec!["Buffalo", "NY"],
-    ];
-    let places = vec![
-        svec!["city", "place"],
-        svec!["Boston", "Logan Airport"],
-        svec!["Boston", "Boston Garden"],
-        svec!["Buffalo", "Ralph Wilson Stadium"],
-        svec!["Orlando", "Disney World"],
-    ];
+//     let cities = vec![
+//         svec!["city", "state"],
+//         svec!["Boston", "MA"],
+//         svec!["New York", "NY"],
+//         svec!["San Francisco", "CA"],
+//         svec!["Buffalo", "NY"],
+//     ];
+//     let places = vec![
+//         svec!["city", "place"],
+//         svec!["Boston", "Logan Airport"],
+//         svec!["Boston", "Boston Garden"],
+//         svec!["Buffalo", "Ralph Wilson Stadium"],
+//         svec!["Orlando", "Disney World"],
+//     ];
 
-    wrk.create("cities.csv", cities.clone());
-    wrk.create("places.csv", places.clone());
+//     wrk.create("cities.csv", cities.clone());
+//     wrk.create("places.csv", places.clone());
 
-    let dp_file = wrk.path("dpdir.json");
-    let dp_file_filename = dp_file.to_string_lossy().to_string();
+//     let dp_file = wrk.path("dpdir.json");
+//     let dp_file_filename = dp_file.to_string_lossy().to_string();
 
-    let mut cmd = wrk.command("to");
-    cmd.arg("datapackage")
-        .arg(dp_file_filename.clone())
-        .arg(wrk.path(""));
+//     let mut cmd = wrk.command("to");
+//     cmd.arg("datapackage")
+//         .arg(dp_file_filename.clone())
+//         .arg(wrk.path(""));
 
-    let got: String = wrk.stdout(&mut cmd);
-    let expected: String = r#"Table 'places' (4 rows)
+//     let got: String = wrk.stdout(&mut cmd);
+//     let expected: String = r#"Table 'places' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-place       string      string
+// Field Name  Field Type  Field Format
+// city        string      string
+// place       string      string
 
-Table 'cities' (4 rows)
+// Table 'cities' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-state       string      string"#
-        .to_string();
+// Field Name  Field Type  Field Format
+// city        string      string
+// state       string      string"#
+//         .to_string();
 
-    let expected2: String = r#"Table 'cities' (4 rows)
+//     let expected2: String = r#"Table 'cities' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-state       string      string
+// Field Name  Field Type  Field Format
+// city        string      string
+// state       string      string
 
-Table 'places' (4 rows)
+// Table 'places' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-place       string      string"#
-        .to_string();
+// Field Name  Field Type  Field Format
+// city        string      string
+// place       string      string"#
+//         .to_string();
 
-    assert!(got == expected || got == expected2);
+//     assert!(got == expected || got == expected2);
 
-    let expected = wrk.load_test_file("dpdir.json");
-    let expected_path = Path::new(&expected);
+//     let expected = wrk.load_test_file("dpdir.json");
+//     let expected_path = Path::new(&expected);
 
-    assert!(is_same_file(&dp_file, expected_path).unwrap());
-}
+//     assert!(is_same_file(&dp_file, expected_path).unwrap());
+// }
 
-#[test]
-fn to_sqlite_dir() {
-    let wrk = Workdir::new("to_sqlite_dir");
+// #[test]
+// fn to_sqlite_dir() {
+//     let wrk = Workdir::new("to_sqlite_dir");
 
-    let cities = vec![
-        svec!["city", "state"],
-        svec!["Boston", "MA"],
-        svec!["New York", "NY"],
-        svec!["San Francisco", "CA"],
-        svec!["Buffalo", "NY"],
-    ];
-    let places = vec![
-        svec!["city", "place"],
-        svec!["Boston", "Logan Airport"],
-        svec!["Boston", "Boston Garden"],
-        svec!["Buffalo", "Ralph Wilson Stadium"],
-        svec!["Orlando", "Disney World"],
-    ];
+//     let cities = vec![
+//         svec!["city", "state"],
+//         svec!["Boston", "MA"],
+//         svec!["New York", "NY"],
+//         svec!["San Francisco", "CA"],
+//         svec!["Buffalo", "NY"],
+//     ];
+//     let places = vec![
+//         svec!["city", "place"],
+//         svec!["Boston", "Logan Airport"],
+//         svec!["Boston", "Boston Garden"],
+//         svec!["Buffalo", "Ralph Wilson Stadium"],
+//         svec!["Orlando", "Disney World"],
+//     ];
 
-    wrk.create("cities.csv", cities.clone());
-    wrk.create("places.csv", places.clone());
+//     wrk.create("cities.csv", cities.clone());
+//     wrk.create("places.csv", places.clone());
 
-    let sqlite_file = wrk.path("test_to_sqlite.db");
-    let sqlite_file_filename = sqlite_file.to_string_lossy().to_string();
+//     let sqlite_file = wrk.path("test_to_sqlite.db");
+//     let sqlite_file_filename = sqlite_file.to_string_lossy().to_string();
 
-    let mut cmd = wrk.command("to");
-    cmd.arg("sqlite")
-        .arg(sqlite_file_filename.clone())
-        .arg(wrk.path("."));
+//     let mut cmd = wrk.command("to");
+//     cmd.arg("sqlite")
+//         .arg(sqlite_file_filename.clone())
+//         .arg(wrk.path("."));
 
-    let got: String = wrk.stdout(&mut cmd);
-    let expected: String = r#"Table 'places' (4 rows)
+//     let got: String = wrk.stdout(&mut cmd);
+//     let expected: String = r#"Table 'places' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-place       string      string
+// Field Name  Field Type  Field Format
+// city        string      string
+// place       string      string
 
-Table 'cities' (4 rows)
+// Table 'cities' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-state       string      string"#
-        .to_string();
+// Field Name  Field Type  Field Format
+// city        string      string
+// state       string      string"#
+//         .to_string();
 
-    let expected2: String = r#"Table 'cities' (4 rows)
+//     let expected2: String = r#"Table 'cities' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-state       string      string
+// Field Name  Field Type  Field Format
+// city        string      string
+// state       string      string
 
-Table 'places' (4 rows)
+// Table 'places' (4 rows)
 
-Field Name  Field Type  Field Format
-city        string      string
-place       string      string"#
-        .to_string();
+// Field Name  Field Type  Field Format
+// city        string      string
+// place       string      string"#
+//         .to_string();
 
-    assert!(got == expected || got == expected2);
+//     assert!(got == expected || got == expected2);
 
-    let db = Connection::open(sqlite_file_filename).unwrap();
-    let mut stmt = db.prepare("SELECT * FROM cities ORDER BY city").unwrap();
-    let cities_iter = stmt
-        .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
-        .unwrap();
-    let cities: Vec<(String, String)> = cities_iter.map(|r| r.unwrap()).collect();
-    assert_eq!(
-        cities,
-        vec![
-            (String::from("Boston"), String::from("MA")),
-            (String::from("Buffalo"), String::from("NY")),
-            (String::from("New York"), String::from("NY")),
-            (String::from("San Francisco"), String::from("CA")),
-        ]
-    );
+//     let db = Connection::open(sqlite_file_filename).unwrap();
+//     let mut stmt = db.prepare("SELECT * FROM cities ORDER BY city").unwrap();
+//     let cities_iter = stmt
+//         .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
+//         .unwrap();
+//     let cities: Vec<(String, String)> = cities_iter.map(|r| r.unwrap()).collect();
+//     assert_eq!(
+//         cities,
+//         vec![
+//             (String::from("Boston"), String::from("MA")),
+//             (String::from("Buffalo"), String::from("NY")),
+//             (String::from("New York"), String::from("NY")),
+//             (String::from("San Francisco"), String::from("CA")),
+//         ]
+//     );
 
-    let mut stmt = db
-        .prepare("SELECT * FROM places ORDER BY city, place")
-        .unwrap();
-    let places_iter = stmt
-        .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
-        .unwrap();
-    let places: Vec<(String, String)> = places_iter.map(|r| r.unwrap()).collect();
-    assert_eq!(
-        places,
-        vec![
-            (String::from("Boston"), String::from("Boston Garden")),
-            (String::from("Boston"), String::from("Logan Airport")),
-            (
-                String::from("Buffalo"),
-                String::from("Ralph Wilson Stadium")
-            ),
-            (String::from("Orlando"), String::from("Disney World")),
-        ]
-    );
-}
+//     let mut stmt = db
+//         .prepare("SELECT * FROM places ORDER BY city, place")
+//         .unwrap();
+//     let places_iter = stmt
+//         .query_map([], |row| Ok((row.get(0).unwrap(), row.get(1).unwrap())))
+//         .unwrap();
+//     let places: Vec<(String, String)> = places_iter.map(|r| r.unwrap()).collect();
+//     assert_eq!(
+//         places,
+//         vec![
+//             (String::from("Boston"), String::from("Boston Garden")),
+//             (String::from("Boston"), String::from("Logan Airport")),
+//             (
+//                 String::from("Buffalo"),
+//                 String::from("Ralph Wilson Stadium")
+//             ),
+//             (String::from("Orlando"), String::from("Disney World")),
+//         ]
+//     );
+// }
 
 #[test]
 fn to_sqlite() {
